@@ -895,16 +895,16 @@ and make_boot_media os arch =
 
   (* Fedora primary architectures. *)
   | Fedora ver, Armv7 ->
-     Location (sprintf "https://mirror.bytemark.co.uk/fedora/linux/releases/%d/Server/armhfp/os/" ver)
+     Location (sprintf "https://lon.mirror.rackspace.com/fedora/releases/%d/Server/armhfp/os/" ver)
 
   | Fedora ver, X86_64 when ver < 21 ->
-     Location (sprintf "https://mirror.bytemark.co.uk/fedora/linux/releases/%d/Fedora/x86_64/os/" ver)
+     Location (sprintf "https://lon.mirror.rackspace.com/fedora/releases/releases/%d/Fedora/x86_64/os/" ver)
 
   | Fedora ver, X86_64 ->
-     Location (sprintf "https://mirror.bytemark.co.uk/fedora/linux/releases/%d/Server/x86_64/os/" ver)
+     Location (sprintf "https://lon.mirror.rackspace.com/fedora/releases/%d/Server/x86_64/os/" ver)
 
   | Fedora ver, Aarch64 ->
-     Location (sprintf "https://mirror.bytemark.co.uk/fedora/linux/releases/%d/Server/aarch64/os/" ver)
+     Location (sprintf "https://lon.mirror.rackspace.com/fedora/releases/%d/Server/aarch64/os/" ver)
 
   (* Fedora secondary architectures.
    * By using dl.fedoraproject.org we avoid randomly using mirrors
@@ -958,6 +958,9 @@ and make_boot_media os arch =
   | RHEL (8, minor), arch ->
      Location (sprintf "http://download.eng.bos.redhat.com/released/rhel-6-7-8/rhel-8/RHEL-8/8.%d.0/BaseOS/%s/os" minor (string_of_arch arch))
 
+  | RHEL (9, minor), arch ->
+     Location (sprintf "http://download.eng.bos.redhat.com/released/rhel-9/RHEL-9/9.%d.0/BaseOS/%s/os" minor (string_of_arch arch))
+
   | Ubuntu (_, dist), X86_64 ->
      Location (sprintf "http://archive.ubuntu.com/ubuntu/dists/%s/main/installer-amd64" dist)
 
@@ -1215,13 +1218,13 @@ and os_variant_of_os ?(for_fedora = false) os arch =
 
     | Alma (major, _), _ -> sprintf "almalinux%d" major
 
-    | CentOS (8, _), _ -> "rhel8.0" (* temporary until osinfo updated *)
+    | CentOS (8, _), _ -> "rhel8.5" (* max version known in Fedora 36 *)
     | CentOS (major, minor), _ when (major, minor) <= (7,0) ->
        sprintf "centos%d.%d" major minor
     | CentOS _, _ -> "centos7.0" (* max version known in Fedora 31 *)
 
-    | CentOSStream 8, _ -> "rhel8.0" (* temporary until osinfo updated *)
-    | CentOSStream _, _ -> "rhel8.0" (* min known version is 8 *)
+    | CentOSStream 8, _ -> "rhel8.5" (* max version known in Fedora 36 *)
+    | CentOSStream _, _ -> "rhel8.5" (* max version known in Fedora 36 *)
 
     | RHEL (6, minor), _ when minor <= 8 ->
        sprintf "rhel6.%d" minor
@@ -1229,7 +1232,7 @@ and os_variant_of_os ?(for_fedora = false) os arch =
     | RHEL (7, minor), _ when minor <= 4 ->
        sprintf "rhel7.%d" minor
     | RHEL (7, _), _ -> "rhel7.5" (* max version known in Fedora 29 *)
-    | RHEL (8, _), _ -> "rhel8.0" (* temporary until osinfo updated *)
+    | RHEL (8, _), _ -> "rhel8.5" (* max version known in Fedora 36 *)
     | RHEL (major, minor), _ ->
        sprintf "rhel%d.%d" major minor
 
@@ -1295,7 +1298,7 @@ and make_rhel_yum_conf major minor arch =
   let buf = Buffer.create 4096 in
   let bpf fs = bprintf buf fs in
 
-  if major <= 8 then (
+  if major <= 9 then (
     let baseurl, srpms, optional =
       match major, arch with
       | 5, (I686|X86_64) ->
@@ -1334,7 +1337,7 @@ and make_rhel_yum_conf major minor arch =
          Some ("Optional",
                sprintf "%s/Server-optional/%s/os" topurl (string_of_arch arch),
                sprintf "%s/Server-optional/source/tree" topurl)
-      | 8, arch ->
+      | (8|9), arch ->
          let topurl =
            sprintf "http://download.devel.redhat.com/released/RHEL-%d/%d.%d.0"
                    major major minor in
@@ -1386,7 +1389,7 @@ keepcache=0
   major lc_name major lc_name optionalsrpms
     )
   ) else (
-    assert false (* not implemented for RHEL major >= 9 *)
+    assert false (* not implemented for RHEL major >= 10 *)
   );
 
   Buffer.contents buf
