@@ -55,7 +55,6 @@
 guestfs_h *g;
 
 int read_only = 1;
-int live = 0;
 int verbose = 0;
 int keys_from_stdin = 0;
 int echo_keys = 0;
@@ -343,7 +342,6 @@ main (int argc, char *argv[])
    */
   assert (read_only == 1);
   assert (inspector == 1 || mps != NULL);
-  assert (live == 0);
 
   CHECK_OPTION_format_consumed;
   CHECK_OPTION_blocksize_consumed;
